### Name: House2001
### Title: Data on twenty roll calls in the US House of Representatives,
###   2001
### Aliases: House2001
### Keywords: datasets

### ** Examples

data(House2001)
summary(House2001)
## Put the votes in a matrix, and discard members with too many NAs etc:
House2001m <- as.matrix(House2001[-1])
informative <- apply(House2001m, 1, function(row){
    valid <- !is.na(row)
    validSum <- if (any(valid)) sum(row[valid]) else 0
    nValid <- sum(valid)
    uninformative <- (validSum == nValid) || (validSum == 0) || (nValid < 10)
    !uninformative})
House2001m <- House2001m[informative, ]
## Make a vector of colours, blue for Republican and red for Democrat:
parties <- House2001$party[informative]
partyColors <- rep("black", length(parties))
partyColors <- ifelse(parties == "D", "red", partyColors)
partyColors <- ifelse(parties == "R", "blue", partyColors)
## Expand the data for statistical modelling:
House2001v <- as.vector(House2001m)
House2001f <- data.frame(member = rownames(House2001m),
                         party = parties,
                         rollCall = factor(rep((1:20),
                                           rep(nrow(House2001m), 20))),
                         vote = House2001v)
## Now fit an "empty" model, in which all members vote identically:
baseModel <- glm(vote ~ -1 + rollCall, family = binomial, data = House2001f)
## From this, get starting values for a one-dimensional multiplicative term:
Start <- residSVD(baseModel, rollCall, member)
##
## Now fit the logistic model with one multiplicative term.
## For the response variable, instead of vote=0,1 we use 0.03 and 0.97,
## corresponding approximately to a bias-reducing adjustment of p/(2n),
## where p is the number of parameters and n the number of observations.
##
voteAdj <- 0.5 + 0.94*(House2001f$vote - 0.5)
House2001model1 <- gnm(voteAdj ~ Mult(rollCall - 1, member - 1),
              eliminate = rollCall,
              family = binomial, data = House2001f,
              na.action = na.exclude, trace = TRUE, tolerance = 1e-03,
              start = -Start)
## Deviance is 2234.847, df = 5574
##
## Plot the members' positions as estimated in the model:
##
memberParameters <- grep("member", names(coef(House2001model1)))
plot(coef(House2001model1)[memberParameters], col = partyColors,
     xlab = "Alphabetical index (Abercrombie 1 to Young 301)",
     ylab = "Member's relative position, one-dimensional model")
## Can do the same thing with two dimensions, but gnm takes around 40
## slow iterations to converge (there are more than 600 parameters): 
## Not run: 
##D Start2 <- residSVD(baseModel, rollCall, member, d = 2)
##D House2001model2 <- gnm(
##D               voteAdj ~ Mult(rollCall - 1, member - 1, multiplicity = 2),
##D               eliminate = rollCall,
##D               family = binomial, data = House2001f,
##D               na.action = na.exclude, trace = TRUE, tolerance = 1e-03,
##D               start = Start2, lsMethod = "qr")
##D ## Deviance is 1545.166, df = 5257
##D ##
##D memberParameters1 <- grep("Mult1.*member", names(coef(House2001model2)))
##D memberParameters2 <- grep("Mult2.*member", names(coef(House2001model2)))
##D plot(coef(House2001model2)[memberParameters1],
##D      coef(House2001model2)[memberParameters2],
##D      col = partyColors,
##D      xlab = "Dimension 1",
##D      ylab = "Dimension 2",
##D      main = "House2001 data: Member positions, 2-dimensional model")
##D ##
##D ## The second dimension is mainly due to rollCall 12, which does not
##D ## correlate well with the rest -- look at the coefficients of
##D ## House2001model1, or at
##D cormat <- cor(na.omit(House2001m))
## End(Not run)



